"""
Individual bot personalities.

Import directly from here to get specific bots.
"""

# This file makes the entire bots directory importable
# For example: from hands_on_ai.chat.personalities.bots import friendly_bot